@@ -3,21 +3,19 @@ from decimal import Decimal
 
 class Item(object):
 
-    def __init__(self, position=0, text='', period='', price=Decimal(0),
-            unit='', quantity=Decimal(1), discount=Decimal(0),
-            vat_rate=Decimal(0)):
+    def __init__(self, position=0, text='', period='', date=None,
+            price=Decimal(0), unit='', quantity=Decimal(1),
+            discount=Decimal(0), vat_rate=Decimal(0)):
         self.position = position
         self.text = text
         self.period = period
+        self.date = date
         self.price = price
         self.unit = unit
         self.quantity = quantity
         self.discount = discount
         self.vat_rate = vat_rate
 
-    def get_unit_display(self):
-        return self.unit
-
     @property
     def subtotal(self):
         return self.price * self.quantity
